@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -42,9 +43,7 @@
 #include <com/sun/star/ui/dialogs/XFilterManager.hpp>
 #include <com/sun/star/ui/dialogs/TemplateDescription.hpp>
 #include <com/sun/star/ui/dialogs/ExtendedFilePickerElementIds.hpp>
-#ifndef _COM_SUN_STAR_SCRIPT_XLIBRYARYCONTAINER2_HPP_
 #include <com/sun/star/script/XLibraryContainer2.hpp>
-#endif
 #include <com/sun/star/document/MacroExecMode.hpp>
 #include <com/sun/star/script/ModuleType.hpp>
 #include <toolkit/helper/vclunohelper.hxx>
@@ -65,10 +64,6 @@
 
 #include <vcl/sound.hxx>
 
-//#ifndef _TXTCMP_HXX //autogen
-//#include <svtools/txtcmp.hxx>
-//#endif
-
 #include <unotools/textsearch.hxx>
 #include <tools/diagnose_ex.h>
 
@@ -348,8 +343,8 @@ BOOL ModulWindow::BasicExecute()
             AddStatus( BASWIN_RUNNINGBASIC );
             USHORT nStart, nEnd, nCurMethodStart = 0;
             TextSelection aSel = GetEditView()->GetSelection();
-            if ( aDocument.isInVBAMode() )
-                nCurMethodStart = ( aSel.GetStart().GetPara() + 1 );
+            // Init cursor to top
+            nCurMethodStart = ( aSel.GetStart().GetPara() + 1 );
             SbMethod* pMethod = 0;
             // erstes Macro, sonst blind "Main" (ExtSearch?)
             for ( USHORT nMacro = 0; nMacro < xModule->GetMethods()->Count(); nMacro++ )
@@ -357,26 +352,17 @@ BOOL ModulWindow::BasicExecute()
                 SbMethod* pM = (SbMethod*)xModule->GetMethods()->Get( nMacro );
                 DBG_ASSERT( pM, "Method?" );
                 pM->GetLineRange( nStart, nEnd );
-                if ( aDocument.isInVBAMode() )
-                {
-                    if (  nCurMethodStart >= nStart && nCurMethodStart <= nEnd ) 
-                    {
-                        pMethod = pM;
-                        break;
-                    }
-                }
-                else if  ( !pMethod || ( nStart < nCurMethodStart && !pM->IsHidden() ) )
+                if (  nCurMethodStart >= nStart && nCurMethodStart <= nEnd )
                 {
+                    // matched a method to the cursor position
                     pMethod = pM;
-                    nCurMethodStart = nStart;
+                    break;
                 }
             }
             if ( !pMethod )
             {
-                if ( aDocument.isInVBAMode() )
-                    return ( BasicIDE::ChooseMacro( uno::Reference< frame::XModel >(), FALSE, rtl::OUString() ).getLength() > 0 ) ? TRUE : FALSE;
-                else
-                    pMethod = (SbMethod*)xModule->Find( String( RTL_CONSTASCII_USTRINGPARAM( "Main" ) ), SbxCLASS_METHOD );
+                // If not in a method then prompt the user
+                return ( BasicIDE::ChooseMacro( uno::Reference< frame::XModel >(), FALSE, rtl::OUString() ).getLength() > 0 ) ? TRUE : FALSE;
             }
             if ( pMethod )
             {
@@ -1769,3 +1755,5 @@ Image ModulWindowLayout::getImage(USHORT nId, bool bHighContrastMode) const
     return (bHighContrastMode ? m_aImagesHighContrast : m_aImagesNormal).
         GetImage(nId);
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
