@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -129,12 +130,12 @@ static string trim_string( const string& rString )
 {
     string temp = rString;
     
-    while ( temp.length() && temp[0] == ' ' || temp[0] == '\t' )
+    while ( temp.length() && (temp[0] == ' ' || temp[0] == '\t') )
         temp.erase( 0, 1 );
         
     string::size_type	len = temp.length();
     
-    while ( len && temp[len-1] == ' ' || temp[len-1] == '\t' )
+    while ( len && (temp[len-1] == ' ' || temp[len-1] == '\t') )
     {
         temp.erase( len - 1, 1 );
         len = temp.length();
@@ -1120,3 +1121,5 @@ int main( int argc, char** argv )
     
     return -1;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
