@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -60,10 +61,6 @@ using namespace ::svtools;
 #define GROUP_BASIC     5
 #define GROUP_SQL		6
 
-/* -----------------------------2002/06/26 10:48------------------------------
-
- ---------------------------------------------------------------------------*/
-
 class SvxExtFixedText_Impl : public FixedText
 {
 private:
@@ -80,9 +77,6 @@ public:
     inline void     SetGroupHeight( long _nHeight ) { m_nGroupHeight = _nHeight; }
 };
 
-/* -----------------------------25.03.2002 15:48------------------------------
-
- ---------------------------------------------------------------------------*/
 class ColorConfigCtrl_Impl;
 class ColorConfigWindow_Impl : public Window
 {
@@ -249,6 +243,9 @@ class ColorConfigWindow_Impl : public Window
     virtual void    Command( const CommandEvent& rCEvt );
     virtual void    DataChanged( const DataChangedEvent& rDCEvt );
 
+    // calculate position behind last chapter
+    sal_Int32 impl_getPosBehindLastChapter() const;
+
 public:
     ColorConfigWindow_Impl(Window* pParent, const ResId& rResId);
     ~ColorConfigWindow_Impl();
@@ -386,7 +383,7 @@ sal_Int16 lcl_getGroup( sal_Int32 _nFeature )
 
 /* -----------------------------25.03.2002 17:05------------------------------
 
- ---------------------------------------------------------------------------*/
+---------------------------------------------------------------------------*/
 ColorConfigWindow_Impl::ColorConfigWindow_Impl(Window* pParent, const ResId& rResId) :
         Window(pParent, rResId),
         aGeneralBackWN(this),
@@ -697,14 +694,14 @@ ColorConfigWindow_Impl::ColorConfigWindow_Impl(Window* pParent, const ResId& rRe
     aChapters[GROUP_CALC    ]->SetGroupHeight( aChapters[GROUP_DRAW]->GetPosPixel().Y() -  aChapters[GROUP_CALC]->GetPosPixel().Y() );
     aChapters[GROUP_DRAW    ]->SetGroupHeight( aChapters[GROUP_BASIC]->GetPosPixel().Y() - aChapters[GROUP_DRAW]->GetPosPixel().Y() );
     aChapters[GROUP_BASIC   ]->SetGroupHeight( aChapters[GROUP_SQL]->GetPosPixel().Y() - aChapters[GROUP_BASIC]->GetPosPixel().Y() );
+    aChapters[GROUP_SQL]->SetGroupHeight(impl_getPosBehindLastChapter()
+            - aChapters[GROUP_SQL]->GetPosPixel().Y());
 
     ExtendedColorConfig aExtConfig;
     sal_Int32 nExtCount = aExtConfig.GetComponentCount();
     if ( nExtCount )
     {
-        // calculate position behind last chapter
-        sal_Int32 nLastY = aSQLCommentWN.GetPosPixel().Y() + aSQLCommentWN.GetSizePixel().Height();
-        nLastY = nLastY + LogicToPixel( Size( 0, 3 ), MAP_APPFONT ).Height();
+        const sal_Int32 nLastY(impl_getPosBehindLastChapter());
         // to calculate the number of lines
         sal_Int32 nHeight = LogicToPixel( Size( 0, _LINE_HEIGHT ), MAP_APPFONT ).Height();
         sal_Int32 nLineNum = nLastY / nHeight;
@@ -864,9 +861,7 @@ ColorConfigWindow_Impl::ColorConfigWindow_Impl(Window* pParent, const ResId& rRe
         }
     }
 }
-/* -----------------------------27.03.2002 11:04------------------------------
 
- ---------------------------------------------------------------------------*/
 ColorConfigWindow_Impl::~ColorConfigWindow_Impl()
 {
     aChapters.clear();
@@ -886,9 +881,15 @@ ColorConfigWindow_Impl::~ColorConfigWindow_Impl()
     aChapterWins.clear();
     ::std::vector< Window*>().swap(aChapterWins);
 }
-/* -----------------------------2002/06/20 12:48------------------------------
 
- ---------------------------------------------------------------------------*/
+sal_Int32
+ColorConfigWindow_Impl::impl_getPosBehindLastChapter() const
+{
+    sal_Int32 nLastY = aSQLCommentWN.GetPosPixel().Y() + aSQLCommentWN.GetSizePixel().Height();
+    nLastY = nLastY + LogicToPixel( Size( 0, 3 ), MAP_APPFONT ).Height();
+    return nLastY;
+}
+
 void ColorConfigWindow_Impl::DataChanged( const DataChangedEvent& rDCEvt )
 {
     Window::DataChanged( rDCEvt );
@@ -905,9 +906,7 @@ void ColorConfigWindow_Impl::DataChanged( const DataChangedEvent& rDCEvt )
         SetBackground(Wallpaper(rStyleSettings.GetWindowColor()));
     }
 }
-/* -----------------------------2002/06/26 10:49------------------------------
 
- ---------------------------------------------------------------------------*/
 void SvxExtFixedText_Impl::DataChanged(const DataChangedEvent& rDCEvt)
 {
     FixedText::DataChanged(rDCEvt);
@@ -946,16 +945,11 @@ void ColorConfigWindow_Impl::SetNewPosition( sal_Int32 _nFeature, Window* _pWin
     }
 }
 
-/* -----------------------------08.04.2002 17:10------------------------------
-
- ---------------------------------------------------------------------------*/
 void ColorConfigWindow_Impl::Command( const CommandEvent& rCEvt )
 {
     GetParent()->Command(rCEvt);
 }
-/* -----------------------------25.03.2002 10:44------------------------------
 
- ---------------------------------------------------------------------------*/
 class ColorConfigCtrl_Impl : public Control
 {
     HeaderBar               aHeaderHB;
@@ -994,9 +988,7 @@ public:
                         ScrollHdl(&aVScroll);
                     }
 };
-/* -----------------------------25.03.2002 17:09------------------------------
 
- ---------------------------------------------------------------------------*/
 ColorConfigCtrl_Impl::ColorConfigCtrl_Impl(
         Window* pParent, const ResId& rResId) :
         Control(pParent, rResId),
@@ -1087,15 +1079,11 @@ ColorConfigCtrl_Impl::ColorConfigCtrl_Impl(
         }
     }
 }
-/* -----------------------------27.03.2002 10:46------------------------------
 
- ---------------------------------------------------------------------------*/
 ColorConfigCtrl_Impl::~ColorConfigCtrl_Impl()
 {
 }
-/* -----------------------------25.03.2002 17:19------------------------------
 
- ---------------------------------------------------------------------------*/
 void ColorConfigCtrl_Impl::Update()
 {
     DBG_ASSERT(pColorConfig, "Configuration not set" );
@@ -1160,12 +1148,10 @@ void ColorConfigCtrl_Impl::Update()
         }
     }
 }
-/* -----------------------------26.03.2002 12:55------------------------------
 
- ---------------------------------------------------------------------------*/
-sal_Bool lcl_MoveAndShow(Window* pWindow, long nOffset, long nMaxVisible, bool _bShow)
+sal_Bool lcl_MoveAndShow(Window* pWindow, long nOffset, long nMaxVisible, sal_Bool _bShow)
 {
-    BOOL bHide = TRUE;
+    sal_Bool bHide = TRUE;
     if(pWindow)
     {
         Point aPos = pWindow->GetPosPixel();
@@ -1194,12 +1180,14 @@ IMPL_LINK(ColorConfigCtrl_Impl, ScrollHdl, ScrollBar*, pScrollBar)
             continue;
         Point aPos;
         //controls outside of the view need to be hidden to speed up accessibility tools
-        bool bShowCtrl = ( lcl_isGroupVisible(
+        sal_Bool bShowCtrl = ( lcl_isGroupVisible(
             lcl_getGroup(i), aScrollWindow.GetModuleOptions() ) != sal_False );
-        lcl_MoveAndShow(aScrollWindow.aCheckBoxes[i], nOffset, nWindowHeight, bShowCtrl);
-        lcl_MoveAndShow(aScrollWindow.aFixedTexts[i], nOffset, nWindowHeight, bShowCtrl);
-        lcl_MoveAndShow(aScrollWindow.aWindows[i]   , nOffset, nWindowHeight, bShowCtrl);
-        BOOL bShow = lcl_MoveAndShow(aScrollWindow.aColorBoxes[i], nOffset, nWindowHeight, bShowCtrl);
+        // if any of the items on the current line is visible, the
+        // whole line should be visible
+        sal_Bool bShow(lcl_MoveAndShow(aScrollWindow.aCheckBoxes[i], nOffset, nWindowHeight, bShowCtrl));
+        bShow = lcl_MoveAndShow(aScrollWindow.aFixedTexts[i], nOffset, nWindowHeight, bShowCtrl) || bShow;
+        bShow = lcl_MoveAndShow(aScrollWindow.aWindows[i]   , nOffset, nWindowHeight, bShowCtrl) || bShow;
+        bShow = lcl_MoveAndShow(aScrollWindow.aColorBoxes[i], nOffset, nWindowHeight, bShowCtrl) || bShow;
         if(bShow)
         {
             if(nFirstVisible == -1)
@@ -1211,7 +1199,7 @@ IMPL_LINK(ColorConfigCtrl_Impl, ScrollHdl, ScrollBar*, pScrollBar)
     //show the one prior to the first visible and the first after the last visble control
     //to enable KEY_TAB travelling
 
-    if(nFirstVisible)
+    if(nFirstVisible > 0)
     {
         //skip gaps where no controls exist for the related ColorConfigEntry
         do
@@ -1256,9 +1244,7 @@ IMPL_LINK(ColorConfigCtrl_Impl, ScrollHdl, ScrollBar*, pScrollBar)
     aScrollWindow.SetUpdateMode(TRUE);
     return 0;
 }
-/* -----------------------------29.04.2002 17:02------------------------------
 
- ---------------------------------------------------------------------------*/
 long ColorConfigCtrl_Impl::PreNotify( NotifyEvent& rNEvt )
 {
     if(rNEvt.GetType() == EVENT_COMMAND)
@@ -1273,9 +1259,7 @@ long ColorConfigCtrl_Impl::PreNotify( NotifyEvent& rNEvt )
     }
     return Control::PreNotify(rNEvt);
 }
-/* -----------------------------08.04.2002 16:37------------------------------
 
- ---------------------------------------------------------------------------*/
 void ColorConfigCtrl_Impl::Command( const CommandEvent& rCEvt )
 {
     switch ( rCEvt.GetCommand() )
@@ -1297,9 +1281,6 @@ void ColorConfigCtrl_Impl::Command( const CommandEvent& rCEvt )
     }
 }
 
-/* -----------------------------14.12.2005 12:37------------------------------
-
- ---------------------------------------------------------------------------*/
 void ColorConfigCtrl_Impl::DataChanged( const DataChangedEvent& rDCEvt )
 {
     Window::DataChanged( rDCEvt );
@@ -1311,10 +1292,6 @@ void ColorConfigCtrl_Impl::DataChanged( const DataChangedEvent& rDCEvt )
     }
 }
 
-
-/* -----------------------------27.03.2002 11:43------------------------------
-
- ---------------------------------------------------------------------------*/
 IMPL_LINK(ColorConfigCtrl_Impl, ClickHdl, CheckBox*, pBox)
 {
     DBG_ASSERT(pColorConfig, "Configuration not set" );
@@ -1330,12 +1307,10 @@ IMPL_LINK(ColorConfigCtrl_Impl, ClickHdl, CheckBox*, pBox)
             pColorConfig->SetColorValue(ColorConfigEntry(i), aBoundCol);
             break;
         }
-    } // for( sal_Int32 i = 0; i < ColorConfigEntryCount; i++ )
+    }
     return 0;
 }
-/* -----------------------------27.03.2002 11:43------------------------------
 
- ---------------------------------------------------------------------------*/
 IMPL_LINK(ColorConfigCtrl_Impl, ColorHdl, ColorListBox*, pBox)
 {
     DBG_ASSERT(pColorConfig, "Configuration not set" );
@@ -1426,9 +1401,7 @@ IMPL_LINK(ColorConfigCtrl_Impl, ControlFocusHdl, Control*, pCtrl)
     }
     return 0;
 };
-/* -----------------------------25.03.2002 10:47------------------------------
 
- ---------------------------------------------------------------------------*/
 SvxColorOptionsTabPage::SvxColorOptionsTabPage(
     Window* pParent, const SfxItemSet& rCoreSet) :
     SfxTabPage( pParent, CUI_RES( RID_SVXPAGE_COLORCONFIG ), rCoreSet ),
@@ -1449,9 +1422,7 @@ SvxColorOptionsTabPage::SvxColorOptionsTabPage(
     aSaveSchemePB.SetClickHdl(aLk);
     aDeleteSchemePB.SetClickHdl(aLk);
 }
-/* -----------------------------25.03.2002 10:47------------------------------
 
- ---------------------------------------------------------------------------*/
 SvxColorOptionsTabPage::~SvxColorOptionsTabPage()
 {
     //when the dialog is cancelled but the color scheme ListBox has been changed these
@@ -1473,16 +1444,12 @@ SvxColorOptionsTabPage::~SvxColorOptionsTabPage()
     pExtColorConfig->EnableBroadcast();
     delete pExtColorConfig;
 }
-/* -----------------------------25.03.2002 10:47------------------------------
 
- ---------------------------------------------------------------------------*/
 SfxTabPage* SvxColorOptionsTabPage::Create( Window* pParent, const SfxItemSet& rAttrSet )
 {
     return ( new SvxColorOptionsTabPage( pParent, rAttrSet ) );
 }
-/* -----------------------------25.03.2002 10:47------------------------------
 
- ---------------------------------------------------------------------------*/
 BOOL SvxColorOptionsTabPage::FillItemSet( SfxItemSet&  )
 {
     bFillItemSetCalled = TRUE;
@@ -1497,9 +1464,7 @@ BOOL SvxColorOptionsTabPage::FillItemSet( SfxItemSet&  )
         pExtColorConfig->Commit();
     return TRUE;
 }
-/* -----------------------------25.03.2002 10:47------------------------------
 
- ---------------------------------------------------------------------------*/
 void SvxColorOptionsTabPage::Reset( const SfxItemSet& )
 {
     if(pColorConfig)
@@ -1533,26 +1498,20 @@ void SvxColorOptionsTabPage::Reset( const SfxItemSet& )
     aDeleteSchemePB.Enable( aSchemes.getLength() > 1 );
     UpdateColorConfig();
 }
-/* -----------------------------25.03.2002 10:47------------------------------
 
- ---------------------------------------------------------------------------*/
 int SvxColorOptionsTabPage::DeactivatePage( SfxItemSet* _pSet )
 {
     if ( _pSet )
         FillItemSet( *_pSet );
     return( LEAVE_PAGE );
 }
-/* -----------------------------25.03.2002 15:32------------------------------
 
- ---------------------------------------------------------------------------*/
 void SvxColorOptionsTabPage::UpdateColorConfig()
 {
     //update the color config control
     pColorConfigCT->Update();
 }
-/* -----------------------------25.03.2002 15:30------------------------------
 
- ---------------------------------------------------------------------------*/
 IMPL_LINK(SvxColorOptionsTabPage, SchemeChangedHdl_Impl, ListBox*, pBox)
 {
     pColorConfig->LoadScheme(pBox->GetSelectEntry());
@@ -1560,37 +1519,33 @@ IMPL_LINK(SvxColorOptionsTabPage, SchemeChangedHdl_Impl, ListBox*, pBox)
     UpdateColorConfig();
     return 0;
 }
-/* -----------------------------09.04.2002 15:21------------------------------
 
- ---------------------------------------------------------------------------*/
 IMPL_LINK(SvxColorOptionsTabPage, SaveDeleteHdl_Impl, PushButton*, pButton )
 {
     if(&aSaveSchemePB == pButton)
     {
         String sName;
-        //CHINA001 SvxNameDialog aNameDlg(pButton,
-        //CHINA001                     sName,
-        //CHINA001                     String(CUI_RES(RID_SVXSTR_COLOR_CONFIG_SAVE2)));
+
         SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
-        DBG_ASSERT(pFact, "Dialogdiet fail!");//CHINA001
+        DBG_ASSERT(pFact, "Dialogdiet fail!");
         AbstractSvxNameDialog* aNameDlg = pFact->CreateSvxNameDialog( pButton,
                             sName, String(CUI_RES(RID_SVXSTR_COLOR_CONFIG_SAVE2)) );
-        DBG_ASSERT(aNameDlg, "Dialogdiet fail!");//CHINA001
+        DBG_ASSERT(aNameDlg, "Dialogdiet fail!");
         aNameDlg->SetCheckNameHdl( LINK(this, SvxColorOptionsTabPage, CheckNameHdl_Impl));
         aNameDlg->SetText(String(CUI_RES(RID_SVXSTR_COLOR_CONFIG_SAVE1)));
         aNameDlg->SetHelpId(HID_OPTIONS_COLORCONFIG_SAVE_SCHEME);
         aNameDlg->SetEditHelpId(HID_OPTIONS_COLORCONFIG_NAME_SCHEME);
         aNameDlg->SetCheckNameHdl( LINK(this, SvxColorOptionsTabPage, CheckNameHdl_Impl));
-        if(RET_OK == aNameDlg->Execute()) //CHINA001 if(RET_OK == aNameDlg.Execute())
+        if(RET_OK == aNameDlg->Execute())
         {
-            aNameDlg->GetName(sName); //CHINA001 aNameDlg.GetName(sName);
+            aNameDlg->GetName(sName);
             pColorConfig->AddScheme(sName);
             pExtColorConfig->AddScheme(sName);
             aColorSchemeLB.InsertEntry(sName);
             aColorSchemeLB.SelectEntry(sName);
             aColorSchemeLB.GetSelectHdl().Call(&aColorSchemeLB);
         }
-        delete aNameDlg; //add by CHINA001
+        delete aNameDlg;
     }
     else
     {
@@ -1611,20 +1566,17 @@ IMPL_LINK(SvxColorOptionsTabPage, SaveDeleteHdl_Impl, PushButton*, pButton )
     aDeleteSchemePB.Enable( aColorSchemeLB.GetEntryCount() > 1 );
     return 0;
 }
-/* -----------------------------09.04.2002 15:47------------------------------
 
- ---------------------------------------------------------------------------*/
 IMPL_LINK(SvxColorOptionsTabPage, CheckNameHdl_Impl, AbstractSvxNameDialog*, pDialog )
 {
     String sName;
     pDialog->GetName(sName);
     return sName.Len() && LISTBOX_ENTRY_NOTFOUND == aColorSchemeLB.GetEntryPos( sName );
 }
-/* -----------------------------25.04.2002 15:12------------------------------
 
- ---------------------------------------------------------------------------*/
 void SvxColorOptionsTabPage::FillUserData()
 {
     SetUserData(String::CreateFromInt32(pColorConfigCT->GetScrollPosition()));
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
