@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -34,17 +35,15 @@
 #include <stardiv/uno/beans/exactname.hxx>
 
 #include <rtl/ustring.hxx>
-#include <vos/dynload.hxx>
-#include <vos/diagnose.hxx>
+#include <osl/diagnose.h>
 #include <usr/services.hxx>
 #include <vcl/svapp.hxx>
 #include <usr/ustring.hxx>
 #include <usr/weak.hxx>
 #include <tools/string.hxx>
-#include <vos/conditn.hxx>
+#include <osl/conditn.hxx>
 
 using namespace rtl;
-using namespace vos;
 using namespace usr;
 
 #define PCHAR_TO_USTRING(x) StringToOUString(String(x),CHARSET_SYSTEM)
@@ -151,7 +150,7 @@ public:
     void cmdLine();
 protected:
 
-    OCondition m_aDebugCondition;
+    osl::Condition m_aDebugCondition;
     XDebuggingRef *m_pDebuggingRef;
     XEngineRef	*m_pEngineRef;
     XInvokationRef *m_pInvokationRef;
@@ -555,3 +554,4 @@ int __LOADONCALLAPI main (int argc, char **argv)
     return 0;
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
