@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -29,9 +30,7 @@
 #include "precompiled_forms.hxx"
 #include "datatypes.hxx"
 #include "resourcehelper.hxx"
-#ifndef _FRM_PROPERTY_HRC_
 #include "property.hrc"
-#endif
 #include "convert.hxx"
 
 /** === begin UNO includes === **/
@@ -993,3 +992,4 @@ namespace xforms
 } // namespace xforms
 //........................................................................
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
